@@ -72,6 +72,7 @@ class DataSource(Dataset):
         self.config = config
         self.training = False  # Flip this flag if you are using the datasource while training
         self.output_weights = None
+        self.output_weights_offset = None
         self.dropout_dict = {}
         self.enable_dropout = False
         self.enable_cache = self.config['data_source']['cache_transformed_data']
@@ -260,6 +261,13 @@ class DataSource(Dataset):
         if self.enable_cache:
             self.transformed_cache[idx] = sample
 
+        if self.output_weights_offset is None:
+            self.output_weights_offset = {}
+            for idx, (otype, oidxs) in enumerate(zip(self.out_types, self.out_indexes)):
+                self.output_weights_offset[idx] = self.output_weights_offset.get(idx-1, 0)
+                if otype not in (ColumnDataTypes.CATEGORICAL, ColumnDataTypes.MULTIPLE_CATEGORICAL):
+                     self.output_weights_offset[idx] += (oidxs[1] - oidxs[0])
+
         return sample
 
     def get_column_original_data(self, column_name):
