@@ -1,12 +1,11 @@
 import traceback
 import time
 
-import dill
-import pickle
 import pandas
 import numpy as np
 import torch
 
+
 from lightwood.api.data_source import DataSource
 from lightwood.data_schemas.predictor_config import predictor_config_schema
 from lightwood.config.config import CONFIG
@@ -24,7 +23,7 @@ class Predictor:
         """
         if load_from_path is not None:
             with open(load_from_path, 'rb') as pickle_in:
-                self_dict = pickle.load(pickle_in)
+                self_dict = torch.load(pickle_in)
             self.__dict__ = self_dict
             self.convert_to_device()
             return
@@ -229,5 +228,5 @@ class Predictor:
 
             # Dump everything relevant to cpu before saving
             self.convert_to_device("cpu")
-            pickle.dump(self.__dict__, f)
+            torch.save(self.__dict__, f)
             self.convert_to_device()
